@@ -67,15 +67,8 @@ class JsonFormatter(logging.Formatter):
         if not self.json_encoder and not self.json_default:
             def _default_json_handler(obj):
                 '''Prints dates in ISO format'''
-                if isinstance(obj, datetime.datetime):
-                    if obj.year < 1900:
-                        # strftime do not work with date < 1900
-                        return obj.isoformat()
-                    return obj.strftime(self.datefmt or '%Y-%m-%dT%H:%M')
-                elif isinstance(obj, datetime.date):
+                if isinstance(obj, (datetime.date, datetime.time)):
                     return obj.isoformat()
-                elif isinstance(obj, datetime.time):
-                    return obj.strftime('%H:%M')
                 elif istraceback(obj):
                     tb = ''.join(traceback.format_tb(obj))
                     return tb.strip()
@@ -109,6 +102,12 @@ class JsonFormatter(logging.Formatter):
         """
         return log_record
 
+    def jsonify_log_record(self, log_record):
+        """Returns a json string of the log record."""
+        return json.dumps(log_record,
+                          default=self.json_default,
+                          cls=self.json_encoder)
+
     def format(self, record):
         """Formats a log record and serializes to json"""
         message_dict = {}
@@ -134,7 +133,4 @@ class JsonFormatter(logging.Formatter):
         self.add_fields(log_record, record, message_dict)
         log_record = self.process_log_record(log_record)
 
-        return "%s%s" % (self.prefix,
-                         json.dumps(log_record,
-                                    default=self.json_default,
-                                    cls=self.json_encoder))
+        return "%s%s" % (self.prefix, self.jsonify_log_record(log_record))
